@@ -1,4 +1,5 @@
 from typing import List
+from urllib.parse import unquote
 
 from fastapi import APIRouter, Body, security, Depends
 
@@ -7,7 +8,6 @@ from entitykb import (
     Doc,
     models,
     Config,
-    Entity,
     Direction,
     exceptions,
     User,
@@ -25,6 +25,7 @@ config = Config.create()
 @router.get("/nodes/{key}", tags=["nodes"])
 async def get_node(key: str) -> dict:
     """ Parse text and return document object. """
+    key = unquote(key)
     async with connection as client:
         data = await client.call("get_node", key)
         if data is None:
@@ -46,20 +47,15 @@ async def remove_node(key: str):
         return await client.call("remove_node", key)
 
 
-@router.get(
-    "/nodes/{key}/neighbors", tags=["nodes"], response_model=List[models.Node]
+@router.post(
+    "/nodes/neighbors",
+    tags=["nodes"],
+    response_model=models.NeighborResponse,
 )
 async def get_neighbors(
-    key: str,
-    verb: str = None,
-    label: str = None,
-    direction: Direction = None,
-    limit: int = 100,
+    request: models.NeighborRequest,
 ) -> List[models.Node]:
     """ Return list of neighbor nodes for a given node. """
-    request = models.EdgeRequest(
-        node_key=key, verb=verb, label=label, direction=direction, limit=limit
-    )
     async with connection as client:
         data = await client.call("get_neighbors", request.dict())
         return data
@@ -70,7 +66,7 @@ async def get_edges(
     key: str, verb: str = None, direction: Direction = None, limit: int = 100
 ):
     """ Return list of edges for a given node. """
-    request = models.EdgeRequest(
+    request = models.NeighborRequest(
         node_key=key, verb=verb, direction=direction, limit=limit
     )
     async with connection as client:
@@ -78,6 +74,13 @@ async def get_edges(
         return data
 
 
+@router.post("/nodes/count", tags=["nodes"])
+async def count_nodes(request: models.CountRequest) -> int:
+    async with connection as client:
+        count = await client.call("count_nodes", request.dict())
+        return count
+
+
 # edges
 
 
@@ -99,16 +102,16 @@ async def parse(request: models.ParseRequest = Body(...)) -> Doc:
         return data
 
 
-@router.post("/find", tags=["pipeline"], response_model=List[Entity])
-async def find(request: models.ParseRequest = Body(...)) -> List[Entity]:
+@router.post("/find", tags=["pipeline"], response_model=List[dict])
+async def find(request: models.ParseRequest = Body(...)) -> List[dict]:
     """ Parse text and return found entities. """
     async with connection as client:
         data = await client.call("find", request.dict())
         return data
 
 
-@router.post("/find_one", tags=["pipeline"], response_model=Entity)
-async def find_one(request: models.ParseRequest = Body(...)) -> Entity:
+@router.post("/find_one", tags=["pipeline"], response_model=dict)
+async def find_one(request: models.ParseRequest = Body(...)) -> dict:
     """ Parse text and return entity, if one and only one found. """
     async with connection as client:
         data = await client.call("find_one", request.dict())
