@@ -7,6 +7,8 @@ from entitykb import (
     Doc,
     Edge,
     Entity,
+    Neighbor,
+    NeighborResponse,
     Node,
     NodeKey,
     SearchResponse,
@@ -88,6 +90,10 @@ class IGraph(object):
     def get_labels(self) -> Set[str]:
         """ Get all labels in graph. """
 
+    @abstractmethod
+    def count_nodes(self, term=None, labels: istr = None) -> int:
+        """ Get counts of nodes for term and labels. """
+
     # edges
 
     @abstractmethod
@@ -112,6 +118,18 @@ class IGraph(object):
     def get_verbs(self) -> Set[str]:
         """ Get all the verbs in graph. """
 
+    @abstractmethod
+    def get_neighbors(
+        self,
+        node_key,
+        verb: str = None,
+        direction: Optional[Direction] = None,
+        label: str = None,
+        offset: int = 0,
+        limit: int = 10,
+    ) -> Tuple[List[Neighbor], int]:
+        """ Get neighbors of a given node. """
+
     # iterate
 
     @abstractmethod
@@ -168,10 +186,18 @@ class IGraph(object):
 
 
 class IFilterer(object):
-    @classmethod
-    @abstractmethod
-    def filter(cls, spans, tokens) -> List[Span]:
-        """ Filter spans based on this filterer's purpose. """
+    """
+    Abstract class that processes spans
+    """
+
+    def __init__(self, doc: Doc = None):
+        self.doc = doc
+
+    def is_keep(self, span: Span):
+        return True
+
+    def filter(self, spans: Iterator[Span]) -> Iterator[Span]:
+        return filter(self.is_keep, spans)
 
 
 class IKnowledgeBase(object):
@@ -207,9 +233,11 @@ class IKnowledgeBase(object):
         self,
         node_key: NodeKey,
         verb: str = None,
-        label: str = None,
         direction: Optional[Direction] = None,
-    ) -> List[Node]:
+        label: str = None,
+        offset: int = 0,
+        limit: int = 10,
+    ) -> NeighborResponse:
         """ Retrieve unique neighbor nodes. """
 
     @abstractmethod
@@ -221,6 +249,10 @@ class IKnowledgeBase(object):
     ) -> List[Edge]:
         """ Get edges for a given Node. """
 
+    @abstractmethod
+    def count_nodes(self, term=None, labels: istr = None):
+        """ Get counts of nodes for term and labels. """
+
     # edges
 
     @abstractmethod
