@@ -17,7 +17,12 @@ from .client_async import AsyncKB
 
 
 def run_future(future):
-    loop = asyncio.get_event_loop()
+    try:
+        loop = asyncio.get_event_loop()
+    except RuntimeError:
+        loop = asyncio.new_event_loop()
+        asyncio.set_event_loop(loop)
+
     result = loop.run_until_complete(future)
     return result
 
@@ -49,16 +54,22 @@ class SyncKB(AsyncKB):
         self,
         node_key: NodeKey,
         verb: str = None,
-        label: str = None,
         direction: Optional[Direction] = None,
-        limit: int = 100,
+        label: str = None,
+        offset: int = 0,
+        limit: int = 10,
     ) -> List[Node]:
         future = super(SyncKB, self).get_neighbors(
-            node_key, verb, label, direction, limit
+            node_key, verb, direction, label, offset, limit
         )
         neighbors = run_future(future)
         return neighbors
 
+    async def count_nodes(self, term=None, labels: istr = None):
+        future = super(SyncKB, self).count_nodes(term, labels)
+        count = run_future(future)
+        return count
+
     # edges
 
     def save_edge(self, edge: Edge):
@@ -93,20 +104,20 @@ class SyncKB(AsyncKB):
     def find(
         self, text: str, labels: istr = None, pipeline: str = "default"
     ) -> List[Entity]:
-        future = super(SyncKB, self).find(
+        future = super(SyncKB, self).parse(
             text=text, labels=labels, pipeline=pipeline
         )
-        entities = run_future(future)
-        return entities
+        doc = run_future(future)
+        return doc.entities
 
     def find_one(
         self, text: str, labels: istr = None, pipeline: str = "default"
     ) -> Entity:
-        future = super(SyncKB, self).find_one(
+        future = super(SyncKB, self).parse(
             text=text, labels=labels, pipeline=pipeline
         )
-        entity = run_future(future)
-        return entity
+        doc = run_future(future)
+        return doc.entities[0] if len(doc.entities) == 1 else None
 
     # graph
 
